# Continuity

Continuity is a local property. A function $f$ is continuous at an interior point $c$ of its domain if

$$\lim_{x \to c} f(x) = f(c).$$

If either $\lim_{x \to c} f(x)$ fails to exist or it exists but is not equal to $f(c)$, then $f$ is discontinuous at $c$.

## Right and left continuity

$f$ is **right continuous** at $c$ thereby having a left endpoint $c$ of its domain if 

$$\lim_{x \downarrow c} f(x) = f(c)$$

and **left continuous** thereby having a right endpoint $c$ if

$$\lim_{x \uparrow c} f(x) = f(c).$$

## Continuity on an interval

$f$ is continuous on the interval $I$ if and only if $f$ is continuous in each point of $I$. In endpoints left/right continuity is sufficient.

$f$ is called a continuous function if and only if $f$ is continuous on its domain.

## Discontinuity

A discontinuity is removable if and only if the limit exists otherwise the discontinuity is non-removable.

## Combining continuous functions

If the functions $f$ and $g$ are both defined on an interval containing $c$ and both are continuous at $c$, then the following functions are also continuous at $c$:

* the sum $f + g$ and the difference $f - g$;
* the product $f g$;
* the constant multiple $k f$, where $k$ is any number;
* the quotient $\frac{f}{g}$, provided $g(c) \neq 0$; and
* the *n*th root $(f(x))^{\frac{1}{n}}$, provided $f(c) > 0$ if $n$ is even.

This may be proved using the various [limit rules](limits.md/#limit-rules).

## The extreme value theorem 

If $f(x)$ is continuous on the closed, bounded interval $[a,b]$, then there exists numbers $p$ and $q$ in $[a,b]$ such that $\forall x \in [a,b]$,

$$f(p) \leq f(x) \leq f(q).$$

Thus, $f$ has the absolute minimum value $m=f(p)$, taken on at the point $p$, and the absolute maximum value $M=f(q)$, taken on at the point $q$. This follows from the consequence of the completeness property of the real numbers. 

## The intermediate value theorem

If $f(x)$ is continuous on the interval $[a,b]$ and if $s$ is a number between $f(a)$ and $f(b)$, then there exists a number $c$ in $[a,b]$ such that $f(c)=s$. This follows from the consequence of the completeness property of the real numbers. 

In particular, a continuous function defined on a closed interval takes on all values between its minimum value $m$ and its maximum value $M$, so its range is also a closed interval, $[m,M]$.