# Functions of several variables

*Definition*: let $D \subseteq \mathbb{R}^m$ with $m>1$, and $f: D \to \mathbb{R}^n$ then $f$ is a function of several variables where:

* for $n=1$, $f$ is a scalar function,
* for $n>1$, $f$ is a vector valued function.

<br>

*Definition*: the domain convention specifies that the domain of a function of $m$ variables is the largest set of points for which the function makes sense as a real number, unless that domain is explicitly stated to be a smaller set. 

## Graphical representations of scalar valued functions

### Graphs

*Definition*: let $D \subseteq \mathbb{R}^2$ and let $f: D \to \mathbb{R}$ then $G_f := \big\{\big(x, y, f(x,y)\big) \;\big|\; (x, y) \in D\big\}$ is the graph of $f$. Observe that $G_f \subseteq \mathbb{R}^3$. 

### Level sets

*Definition*: let $D \subseteq \mathbb{R}^2$ and let $f: D \to \mathbb{R}$ then for $c \in \mathbb{R}$ we have $S_c := \big\{(x, y) \in D \;\big|\; f(x,y) = c \big\}$ is the level set of $f$. Observe that $S_c \subseteq \mathbb{R}^2$. 

## Multi-index notation

*Definition*: an $n$-dimensional multi-index is an $n$-tuple of non-negative integers

$$
    \alpha = (\alpha_1, \alpha_2, \dotsc, \alpha_n), \qquad \text{with } \alpha_i \in \mathbb{N}.
$$

### Properties

For the sum of components we have: $|\alpha| := \alpha_1 + \dotsc + \alpha_n$. 

For $n$-dimensional multi-indeces $\alpha, \beta$ we have componentwise sum and difference

$$
    \alpha \pm \beta := (\alpha_1 \pm \beta_1, \dotsc, \alpha_n \pm \beta_n).
$$

For the products of powers with $\mathbf{x} \in \mathbb{R}^n$ we have

$$
    \mathbf{x}^\alpha := x_1^{\alpha_1} x_2^{\alpha_2} \dotsc x_n^{\alpha_n}.
$$

For factorials we have

$$
    \alpha ! = \alpha_1 ! \cdot \alpha_2 ! \cdots \alpha_n !
$$

For the binomial coefficient we have

$$
    \begin{pmatrix} \alpha \\ \beta \end{pmatrix} = \begin{pmatrix} \alpha_1 \\ \beta_1 \end{pmatrix} \begin{pmatrix} \alpha_2 \\ \beta_2 \end{pmatrix} \cdots \begin{pmatrix} \alpha_n \\ \beta_n \end{pmatrix} = \frac{\alpha !}{\beta ! (\alpha - \beta)!}
$$

For polynomials of degree less or equal to $m$ we have

$$
    p(\mathbf{x}) = \sum_{|\alpha| \leq m} c_\alpha \mathbf{x}^\alpha,
$$

as an example for $m=2$ and $n=2$ we have

$$
    p(\mathbf{x}) = c_1 + c_2 x_1 + c_3 x_2 + c_4 x_1 x_2 + c_5 x_1 ^2 + c_6 x_2^2 \qquad c_{1,2,3,4,5,6} \in \mathbb{R}
$$

For partial derivatives of $f: \mathbb{R}^n \to \mathbb{R}$ we have

$$
    \partial^\alpha f(\mathbf{x}) = \partial^{\alpha_1}_{x_1} \dotsc \partial^{\alpha_n}_{x_n} f(\mathbf{x}).
$$
